@@ -38,7 +38,7 @@ def get_intrinsic_functions_map(manifest_name, puppet_account_id):
         if os.path.exists(intrinsic_function_file):
             logger.info(f"reading {intrinsic_function_file}")
             intrinsic_function_file_content = (
-                    "[Custom]\n" + open(intrinsic_function_file).read()
+                "[Custom]\n" + open(intrinsic_function_file).read()
             )
             parser.read_string(intrinsic_function_file_content)
             for section_name, section_values in parser.items():
@@ -205,9 +205,9 @@ def expand_manifest(manifest, client):
         account_id = account.get("account_id")
         if account.get("append") or account.get("overwrite"):
             if (
-                    account.get("default_region")
-                    or account.get("regions_enabled")
-                    or account.get("tags")
+                account.get("default_region")
+                or account.get("regions_enabled")
+                or account.get("tags")
             ):
                 raise Exception(
                     f"{account_id}: If using append or overwrite you cannot set default_region, regions_enabled or tags"
@@ -246,7 +246,7 @@ def expand_manifest(manifest, client):
     for section in [constants.LAUNCHES, constants.STACKS]:
         for name, details in new_manifest.get(section, {}).items():
             for parameter_name, parameter_details in details.get(
-                    "parameters", {}
+                "parameters", {}
             ).items():
                 if parameter_details.get("macro"):
                     macro_to_run = macros.get(
@@ -333,14 +333,14 @@ def rewrite_cfct(manifest):
                     m = re.match(r"\$\[alfred_ssm_(.*)\]", parameter_value)
                     if m:
                         parameters[parameter_key] = dict(
-                            ssm=dict(name=m.group(1), region=default_region, )
+                            ssm=dict(name=m.group(1), region=default_region,)
                         )
                     else:
                         parameters[parameter_key] = dict(default=parameter_value)
 
                 if prev is not None:
                     depends_on.append(
-                        dict(name=prev, type=constants.STACK, affinity=constants.STACK, )
+                        dict(name=prev, type=constants.STACK, affinity=constants.STACK,)
                     )
 
                 for output in resource.get("export_outputs", []):
@@ -353,7 +353,7 @@ def rewrite_cfct(manifest):
 
                 regions = resource.get("regions", [default_region])
                 for account in resource.get("deployment_targets", {}).get(
-                        "accounts", []
+                    "accounts", []
                 ):
                     if re.match(r"[0-9]{12}", str(account)):
                         deploy_to_accounts.append(
@@ -372,7 +372,7 @@ def rewrite_cfct(manifest):
                         )
 
                 for organizational_unit in resource.get("deployment_targets", {}).get(
-                        "organizational_units", []
+                    "organizational_units", []
                 ):
                     deploy_to_tags.append(
                         dict(
@@ -424,7 +424,7 @@ def rewrite_cfct(manifest):
 
                 regions = "home_region"
                 for account in resource.get("deployment_targets", {}).get(
-                        "accounts", []
+                    "accounts", []
                 ):
                     if re.match(r"[0-9]{12}", str(account)):
                         deploy_to_accounts.append(
@@ -443,7 +443,7 @@ def rewrite_cfct(manifest):
                         )
 
                 for organizational_unit in resource.get("deployment_targets", {}).get(
-                        "organizational_units", []
+                    "organizational_units", []
                 ):
                     deploy_to_ous.append(dict(ou=organizational_unit, regions=regions))
 
@@ -472,8 +472,8 @@ def rewrite_cfct(manifest):
 
 def rewrite_depends_on(manifest):
     for (
-            section_item_name,
-            section_name,
+        section_item_name,
+        section_name,
     ) in constants.ALL_SECTION_NAME_SINGULAR_AND_PLURAL_LIST:
         for item, details in manifest.get(section_name, {}).items():
             for i in range(len(details.get("depends_on", []))):
@@ -497,12 +497,12 @@ def rewrite_ssm_parameters(manifest):
     :return:
     """
     for (
-            section_item_name,
-            section_name,
+        section_item_name,
+        section_name,
     ) in constants.SECTION_NAME_SINGULAR_AND_PLURAL_LIST_THAT_SUPPORTS_PARAMETERS:
         for item, details in manifest.get(section_name, {}).items():
             for parameter_name, parameter_details in details.get(
-                    "parameters", {}
+                "parameters", {}
             ).items():
                 if parameter_details.get("ssm"):
                     for d in details.get("depends_on", []):
@@ -511,7 +511,7 @@ def rewrite_ssm_parameters(manifest):
                         ).get(d.get("name"))
                         for output in dependency.get("outputs", {}).get("ssm", []):
                             if output.get("param_name") == parameter_details.get(
-                                    "ssm"
+                                "ssm"
                             ).get("name"):
                                 parameter_depends_on = parameter_details["ssm"].get(
                                     "depends_on", []
@@ -560,7 +560,9 @@ def rewrite_ssm_parameters(manifest):
                         filter=f"Outputs[?OutputKey==`{output_key}`].OutputValue | [0]",
                     )
                     parameter_details["boto3"] = new_parameter
-                    for section_item_name, section_item_details in manifest.get(constants.LAUNCHES, {}).items():
+                    for section_item_name, section_item_details in manifest.get(
+                        constants.LAUNCHES, {}
+                    ).items():
                         if section_item_name == provisioned_product_name:
                             if details.get("depends_on") is None:
                                 details["depends_on"] = list()
@@ -602,8 +604,8 @@ def rewrite_stacks(manifest, puppet_account_id):
                 del details["version"]
                 if category == constants.STACK:
                     if (
-                            details.get(constants.MANIFEST_SHOULD_USE_STACKS_SERVICE_ROLE)
-                            is None
+                        details.get(constants.MANIFEST_SHOULD_USE_STACKS_SERVICE_ROLE)
+                        is None
                     ):
                         details[
                             constants.MANIFEST_SHOULD_USE_STACKS_SERVICE_ROLE
@@ -738,7 +740,7 @@ class Manifest(dict):
         return self.get(constants.APPS).get(name)
 
     def get_tasks_for(
-            self, puppet_account_id, section_name, item_name, single_account="None"
+        self, puppet_account_id, section_name, item_name, single_account="None"
     ):
         accounts = self.get(constants.ACCOUNTS)
         section = self.get(section_name)
@@ -760,8 +762,8 @@ class Manifest(dict):
         }.get(section_name)
 
         if (
-                section_name == constants.SPOKE_LOCAL_PORTFOLIOS
-                and item.get(deploy_to) is None
+            section_name == constants.SPOKE_LOCAL_PORTFOLIOS
+            and item.get(deploy_to) is None
         ):
             deploy_to = "deploy_to"
 
@@ -923,8 +925,8 @@ class Manifest(dict):
                         account_id=account_id,
                         account_parameters=account.get("parameters", {}),
                     ),
-                    "spoke-local-portfolios": dict(account_id=account_id, ),
-                    "assertions": dict(account_id=account_id, ),
+                    "spoke-local-portfolios": dict(account_id=account_id,),
+                    "assertions": dict(account_id=account_id,),
                     "lambda-invocations": dict(
                         account_id=account_id,
                         account_parameters=account.get("parameters", {}),
@@ -936,8 +938,8 @@ class Manifest(dict):
                     "service-control-policies": dict(
                         account_id=account_id, ou_name="",
                     ),
-                    "tag-policies": dict(account_id=account_id, ou_name="", ),
-                    constants.SIMULATE_POLICIES: dict(account_id=account_id, ),
+                    "tag-policies": dict(account_id=account_id, ou_name="",),
+                    constants.SIMULATE_POLICIES: dict(account_id=account_id,),
                 }.get(section_name)
                 if tag_name in account.get("tags"):
                     if isinstance(regions, str):
@@ -1027,8 +1029,8 @@ class Manifest(dict):
                     account_id=account_id,
                     account_parameters=account.get("parameters", {}),
                 ),
-                "spoke-local-portfolios": dict(account_id=account_id, ),
-                "assertions": dict(account_id=account_id, ),
+                "spoke-local-portfolios": dict(account_id=account_id,),
+                "assertions": dict(account_id=account_id,),
                 "lambda-invocations": dict(
                     account_id=account_id,
                     account_parameters=account.get("parameters", {}),
@@ -1037,9 +1039,9 @@ class Manifest(dict):
                     account_id=account_id,
                     account_parameters=account.get("parameters", {}),
                 ),
-                "service-control-policies": dict(account_id=account_id, ou_name="", ),
-                "tag-policies": dict(account_id=account_id, ou_name="", ),
-                constants.SIMULATE_POLICIES: dict(account_id=account_id, ),
+                "service-control-policies": dict(account_id=account_id, ou_name="",),
+                "tag-policies": dict(account_id=account_id, ou_name="",),
+                constants.SIMULATE_POLICIES: dict(account_id=account_id,),
             }.get(section_name)
 
             if isinstance(regions, str):
@@ -1120,8 +1122,8 @@ class Manifest(dict):
                 continue
 
             additional_parameters = {
-                "service-control-policies": dict(account_id="", ou_name=ou_name, ),
-                "tag-policies": dict(account_id="", ou_name=ou_name, ),
+                "service-control-policies": dict(account_id="", ou_name=ou_name,),
+                "tag-policies": dict(account_id="", ou_name=ou_name,),
             }.get(section_name)
 
             if isinstance(regions, str) and regions == "home_region":
@@ -1140,12 +1142,12 @@ class Manifest(dict):
         return provisioning_tasks
 
     def get_tasks_for_launch_and_region(
-            self,
-            puppet_account_id,
-            section_name,
-            launch_name,
-            region,
-            single_account="None",
+        self,
+        puppet_account_id,
+        section_name,
+        launch_name,
+        region,
+        single_account="None",
     ):
         return [
             task
@@ -1159,12 +1161,12 @@ class Manifest(dict):
         ]
 
     def get_tasks_for_launch_and_account(
-            self,
-            puppet_account_id,
-            section_nam,
-            launch_name,
-            account_id,
-            single_account="None",
+        self,
+        puppet_account_id,
+        section_nam,
+        launch_name,
+        account_id,
+        single_account="None",
     ):
         return [
             task
@@ -1178,13 +1180,13 @@ class Manifest(dict):
         ]
 
     def get_tasks_for_launch_and_account_and_region(
-            self,
-            puppet_account_id,
-            section_name,
-            launch_name,
-            account_id,
-            region,
-            single_account="None",
+        self,
+        puppet_account_id,
+        section_name,
+        launch_name,
+        account_id,
+        region,
+        single_account="None",
     ):
         return [
             task
@@ -1198,7 +1200,7 @@ class Manifest(dict):
         ]
 
     def get_regions_used_for_section_item(
-            self, puppet_account_id, section_name, item_name
+        self, puppet_account_id, section_name, item_name
     ):
         return list(
             set(
@@ -1210,7 +1212,7 @@ class Manifest(dict):
         )
 
     def get_account_ids_used_for_section_item(
-            self, puppet_account_id, section_name, item_name
+        self, puppet_account_id, section_name, item_name
     ):
         return list(
             set(
@@ -1222,7 +1224,7 @@ class Manifest(dict):
         )
 
     def get_account_ids_and_regions_used_for_section_item(
-            self, puppet_account_id, section_name, item_name
+        self, puppet_account_id, section_name, item_name
     ):
         result = dict()
         for task in self.get_tasks_for(puppet_account_id, section_name, item_name):
@@ -1281,9 +1283,9 @@ class Manifest(dict):
             account_regions.append(account.get("default_region"))
 
             enabled_regions = (
-                    account.get("enabled", [])
-                    + account.get("regions_enabled", [])
-                    + account.get("enabled_regions", [])
+                account.get("enabled", [])
+                + account.get("regions_enabled", [])
+                + account.get("enabled_regions", [])
             )
             if len(enabled_regions) == 0:
                 raise Exception(
@@ -1297,8 +1299,8 @@ class Manifest(dict):
                 if account.get("organization", "") != "":
                     organization = account.get("organization")
                     if (
-                            organization
-                            not in sharing_policies_by_region[r]["organizations"]
+                        organization
+                        not in sharing_policies_by_region[r]["organizations"]
                     ):
                         sharing_policies_by_region[r]["organizations"].append(
                             organization
@@ -1348,11 +1350,11 @@ class Manifest(dict):
         return accounts_by_region
 
     def get_task_defs_from_details(
-            self,
-            puppet_account_id,
-            launch_name,
-            configuration,
-            launch_or_spoke_local_portfolio,
+        self,
+        puppet_account_id,
+        launch_name,
+        configuration,
+        launch_or_spoke_local_portfolio,
     ):
         launch_details = self.get(launch_or_spoke_local_portfolio).get(launch_name)
         accounts = self.get("accounts")
@@ -1494,10 +1496,10 @@ def convert_to_graph(expanded_manifest, G):
     for section in constants.ALL_SECTION_NAMES:
         for item_name, item_details in expanded_manifest.get(section, {}).items():
             uid = f"{section}|{item_name}"
-            data = dict(section=section, item_name=item_name, )
+            data = dict(section=section, item_name=item_name,)
             data.update(item_details)
             G.add_nodes_from(
-                [(uid, data), ]
+                [(uid, data),]
             )
 
     for section in constants.ALL_SECTION_NAMES:
@@ -1563,7 +1565,9 @@ def isolate(expanded_manifest, subset):
             del data["item_name"]
             m[node.get("section")][node.get("item_name")] = data
 
-            for dependency in nx.edge_dfs(G, reverse_dependency_name, orientation="original"):
+            for dependency in nx.edge_dfs(
+                G, reverse_dependency_name, orientation="original"
+            ):
                 link, dependency_name, direction = dependency
                 node = G.nodes.get(dependency_name)
                 data = deepcopy(node)
